Density, distribution function, quantile function, random generation, and hazard function for the Modified Weibull distribution (MWD) introduced by Lai et al. (2003).

dMweibull(x, a, b, lambda, log = FALSE)

pMweibull(q, a, b, lambda, lower.tail = TRUE, log = FALSE)

qMweibull(p, a, b, lambda, lower.tail = TRUE)

rMweibull(n, a, b, lambda)

hMweibull(x, a, b, lambda, log = FALSE)

Arguments

x

Numeric vector of observations.

a

Positive scale parameter (\(a > 0\)).

b

Non-negative shape parameter (\(b \ge 0\)).

lambda

Non-negative parameter (\(\lambda \ge 0\)) controlling the growth rate of the hazard function.

log

Logical. If TRUE, returns log-density, log-distribution, or log-hazard values where applicable.

q

Numeric vector of quantiles.

lower.tail

Logical. If FALSE, returns \(1 - F(x)\) and computes quantiles for \(1 - p\).

#' The Modified Weibull distribution with parameters \(a\), \(b\), and \(\lambda\) has cumulative distribution function (CDF), probability density function (PDF), and hazard function given by

p

Numeric vector of probabilities in \([0,1]\).

n

Integer; number of observations to be generated.

Value

  • dMweibull: Density values.

  • pMweibull: Distribution function values.

  • qMweibull: Quantiles.

  • rMweibull: Random deviates.

  • hMweibull: Hazard function values.

Details

Modified Weibull Distribution

The Modified Weibull distribution with parameters \(a\), \(b\) and \(\lambda\) has cumulative distribution function (CDF), probability density function (PDF), and hazard function given by

$$F(x) = 1 - \exp\left(-a x^b \exp(\lambda x)\right),$$ $$f(x) = a (b + \lambda x) x^{b - 1} \exp(\lambda x) \exp\left(-a x^b \exp(\lambda x)\right),$$ $$h(x) = a (b + \lambda x) x^{b - 1} \exp(\lambda x),$$

where \(x > 0\), \(a > 0\) is the scale parameter, \(b \ge 0\) is a shape parameter, and \(\lambda \ge 0\) is an acceleration or flexibility parameter that controls how quickly the hazard grows over time.

Special cases:

  • If \(\lambda = 0\), the MWD reduces to the Weibull distribution \(F(x) = 1 - \exp(-a x^b)\).

  • If \(b = 0\), the MWD reduces to a type I extreme-value (log-gamma) distribution \(F(x) = 1 - \exp(-a \exp(\lambda x))\).

References

Lai, C. D., Xie, M., and Murthy, D. N. P. (2003). A modified Weibull distribution. IEEE Transactions on Reliability, 52(1), 33–37.

Examples

n <- 25
a <- 0.75; b <- 1.25; lambda <- 0.60
set.seed(123)
x <- rlnorm(n)
ff <- dMweibull(x, a, b, lambda)
FF <- pMweibull(x, a, b, lambda)
qq <- qMweibull(runif(n), a, b, lambda)
dat <- rMweibull(n, a, b, lambda)
hf <- hMweibull(x, a, b, lambda )