R/reliability.R
Reliability_Clayton_MWD.RdComputes the stress–strength reliability (SSR) \(R = P(X > Y)\), where \(X \sim \text{MWD}(a_1, b_1, \lambda_1)\) (strength) and \(Y \sim \text{MWD}(a_2, b_2, \lambda_2)\) (stress), with dependence modeled using a Clayton copula.
Reliability_Clayton_MWD(a1, b1, lambda1, a2, b2, lambda2, theta)A list identical to the output of stats::integrate:
Numerical value of the integral (reliability value).
Estimated absolute error of the numerical integration.
Stress–Strength Reliability under Clayton Copula with MWD Marginals
The stress–strength reliability is defined as \(R = P(X > Y)\), which can be expressed using the joint distribution induced by the Clayton copula.
In copula form, the reliability is computed as $$ R = \int_{0}^{\infty} F_X(x)^{-(\theta + 1)} \left( F_X(x)^{-\theta} + G_Y(x)^{-\theta} - 1 \right)^{-\left(\frac{1}{\theta}+1\right)} f_X(x)\, dx, $$ which can also be written as $$ R = \int_{0}^{1} t^{-(\theta + 1)} \left( t^{-\theta} + G_Y(F_X^{-1}(t))^{-\theta} - 1 \right)^{-\left(\frac{1}{\theta}+1\right)} dt, $$
where \(F_X(x) = 1 - \exp(-a_1 x^{b_1} e^{\lambda_1 x})\) and \(G_Y(y) = 1 - \exp(-a_2 y^{b_2} e^{\lambda_2 y})\).
Further theoretical details can be found in
vignette("ssr-theory", package = "SSReliabilityClaytonMWD")
and Kizilaslan (2026).
Kizilaslan, F. (2026). Reliability estimation in dependent stress–strength model with Clayton copula and modified Weibull margins. arXiv:2604.12130
a1 <- 0.75; b1 <- 1.5; lambda1 <- 0.6
a2 <- 1.2; b2 <- 0.5; lambda2 <- 0.9
theta <- 1 # 2, 3, 4, 5
R <- Reliability_Clayton_MWD(a1, b1, lambda1, a2, b2, lambda2, theta)
R$value
#> [1] 0.8805338
# approximated reliability R based on MC method
R_MC <- Reliability_Clayton_MWD_MC(a1, b1, lambda1, a2, b2, lambda2, theta, N = 50000)
R_MC$R
#> [1] 0.8799547