Prints results of an object of class SSRfit produced by
fit.SSR.ClaytonMWD. The output includes parameter estimates and
confidence interval estimates obtained using MLE, LSE, WLSE, and MPS,
for the marginal parameters, the Clayton copula parameter \(\theta\),
and the reliability measure \(R\).
# S3 method for class 'SSRfit'
print(x, ...)Invisibly returns the input object x of class "SSRfit".
The function is called for its side effects, namely printing formatted
summaries of parameter estimates, dependence parameter estimates,
and associated confidence intervals to the console.
Print SSR Fit Results (Clayton Copula with MWD Marginals)
This method organizes and displays results in a structured format, separating point estimates and interval estimates for all model components.
data = list(X = TerkosDam, Y = OmerliDam)
fit.SSR = fit.SSR.ClaytonMWD(data, ACI = TRUE, bootstrap = TRUE, B = 5,
seed = 2026, one.step = TRUE, alpha = 0.05)
print(fit.SSR)
#>
#> Fitting Results of Stress-Strength Reliability Model with MWD Marginals via Clayton Copula
#>
#>
#> Table: Parameter Estimates
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:----|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |mle | 0.98542| 2.66095| 2.11322| 0.02428| 0.45908| 6.33059| 0.50551| 0.50428|
#> |lse | 0.07196| 1.72091| 5.71667| 0.01166| 0.00001| 7.06623| 1.09884| 0.49349|
#> |wlse | 0.04261| 1.29079| 6.20629| 0.01154| 0.00001| 7.10656| 1.23631| 0.49824|
#> |mps | 0.68997| 2.31111| 2.39000| 0.02043| 0.26258| 6.43699| 0.92547| 0.51110|
#>
#>
#> Table: 95% Asymptotic Confidence Intervals (MLE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.00000| 0.43992| 0.00000| 0.00000| 0.00000| 4.21722| 0.14734| 0.40310|
#> |upper | 4.33682| 4.88197| 5.79639| 0.06723| 1.39756| 8.44395| 0.86369| 0.60545|
#> |length | 4.33682| 4.44205| 5.79639| 0.06723| 1.39756| 4.22673| 0.71636| 0.20235|
#>
#>
#> Table: 95% Bootstrap CIs (MLE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.06764| 1.11748| 0.24777| 0.03399| 0.35264| 3.06021| 0.32101| 0.46058|
#> |upper | 6.38821| 3.86279| 5.14100| 0.64698| 2.66466| 6.31054| 0.76780| 0.57723|
#> |length | 6.32057| 2.74531| 4.89323| 0.61300| 2.31202| 3.25033| 0.44679| 0.11665|
#>
#>
#> Table: 95% Bootstrap CIs (LSE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|--------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.00541| 0.01570| 0.20336| 0.00731| 0.00001| 3.20366| 0.76563| 0.40414|
#> |upper | 14.54734| 5.14369| 8.55168| 0.52132| 3.04501| 7.79835| 1.16978| 0.49216|
#> |length | 14.54193| 5.12799| 8.34832| 0.51400| 3.04500| 4.59469| 0.40415| 0.08802|
#>
#>
#> Table: 95% Bootstrap CIs (WLSE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.00562| 0.03705| 2.04712| 0.01145| 0.00402| 4.57018| 1.02749| 0.40953|
#> |upper | 2.01656| 3.85187| 8.41870| 0.14418| 2.20315| 7.24552| 2.83335| 0.49906|
#> |length | 2.01094| 3.81482| 6.37159| 0.13273| 2.19913| 2.67535| 1.80586| 0.08953|
#>
#>
#> Table: 95% Bootstrap CIs (MPS)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.05764| 0.85330| 0.15124| 0.00905| 0.01090| 3.83919| 0.37910| 0.46552|
#> |upper | 5.12297| 3.58393| 4.96806| 0.25021| 1.89687| 7.46643| 5.52486| 0.61246|
#> |length | 5.06533| 2.73063| 4.81682| 0.24116| 1.88596| 3.62724| 5.14576| 0.14695|
#>
#> Kendall's tau estimate for theta: 1.25912
print(fit.SSR, 3)
#>
#> Fitting Results of Stress-Strength Reliability Model with MWD Marginals via Clayton Copula
#>
#>
#> Table: Parameter Estimates
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:----|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |mle | 0.98542| 2.66095| 2.11322| 0.02428| 0.45908| 6.33059| 0.50551| 0.50428|
#> |lse | 0.07196| 1.72091| 5.71667| 0.01166| 0.00001| 7.06623| 1.09884| 0.49349|
#> |wlse | 0.04261| 1.29079| 6.20629| 0.01154| 0.00001| 7.10656| 1.23631| 0.49824|
#> |mps | 0.68997| 2.31111| 2.39000| 0.02043| 0.26258| 6.43699| 0.92547| 0.51110|
#>
#>
#> Table: 95% Asymptotic Confidence Intervals (MLE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.00000| 0.43992| 0.00000| 0.00000| 0.00000| 4.21722| 0.14734| 0.40310|
#> |upper | 4.33682| 4.88197| 5.79639| 0.06723| 1.39756| 8.44395| 0.86369| 0.60545|
#> |length | 4.33682| 4.44205| 5.79639| 0.06723| 1.39756| 4.22673| 0.71636| 0.20235|
#>
#>
#> Table: 95% Bootstrap CIs (MLE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.06764| 1.11748| 0.24777| 0.03399| 0.35264| 3.06021| 0.32101| 0.46058|
#> |upper | 6.38821| 3.86279| 5.14100| 0.64698| 2.66466| 6.31054| 0.76780| 0.57723|
#> |length | 6.32057| 2.74531| 4.89323| 0.61300| 2.31202| 3.25033| 0.44679| 0.11665|
#>
#>
#> Table: 95% Bootstrap CIs (LSE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|--------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.00541| 0.01570| 0.20336| 0.00731| 0.00001| 3.20366| 0.76563| 0.40414|
#> |upper | 14.54734| 5.14369| 8.55168| 0.52132| 3.04501| 7.79835| 1.16978| 0.49216|
#> |length | 14.54193| 5.12799| 8.34832| 0.51400| 3.04500| 4.59469| 0.40415| 0.08802|
#>
#>
#> Table: 95% Bootstrap CIs (WLSE)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.00562| 0.03705| 2.04712| 0.01145| 0.00402| 4.57018| 1.02749| 0.40953|
#> |upper | 2.01656| 3.85187| 8.41870| 0.14418| 2.20315| 7.24552| 2.83335| 0.49906|
#> |length | 2.01094| 3.81482| 6.37159| 0.13273| 2.19913| 2.67535| 1.80586| 0.08953|
#>
#>
#> Table: 95% Bootstrap CIs (MPS)
#>
#> | | a1| b1| lambda1| a2| b2| lambda2| theta| R|
#> |:------|-------:|-------:|-------:|-------:|-------:|-------:|-------:|-------:|
#> |lower | 0.05764| 0.85330| 0.15124| 0.00905| 0.01090| 3.83919| 0.37910| 0.46552|
#> |upper | 5.12297| 3.58393| 4.96806| 0.25021| 1.89687| 7.46643| 5.52486| 0.61246|
#> |length | 5.06533| 2.73063| 4.81682| 0.24116| 1.88596| 3.62724| 5.14576| 0.14695|
#>
#> Kendall's tau estimate for theta: 1.25912